@@ -1,7 +1,7 @@
 -- -
 -- #%L
 -- %%
--- Copyright (C) 2005 - 2025 Kuali, Inc. - All Rights Reserved
+-- Copyright (C) 2005 - 2026 Kuali, Inc. - All Rights Reserved
 -- %%
 -- You may use and modify this code under the terms of the Kuali, Inc.
 -- Pre-Release License Agreement. You may not distribute it.
@@ -11,5 +11,7 @@
 -- #L%
 -- -
 
-ALTER TABLE S2S_OPPORTUNITY_CFDA
-  MODIFY CFDA_NUMBER VARCHAR(7) NOT NULL;
+delete from S2S_OPPORTUNITY_CFDA where trim(CFDA_NUMBER) = '';
+delete from EPS_PROP_CFDA where trim(CFDA_NUMBER) = '';
+delete from PROPOSAL_CFDA where trim(CFDA_NUMBER) = '';
+delete from AWARD_CFDA where trim(CFDA_NUMBER) = '';
