@@ -1,7 +1,7 @@
 -- -
 -- #%L
 -- %%
--- Copyright (C) 2005 - 2025 Kuali, Inc. - All Rights Reserved
+-- Copyright (C) 2005 - 2026 Kuali, Inc. - All Rights Reserved
 -- %%
 -- You may use and modify this code under the terms of the Kuali, Inc.
 -- Pre-Release License Agreement. You may not distribute it.
@@ -13,6 +13,6 @@
 
 DELIMITER /
 
-update KRIM_PERM_T t set NM='Take Requested Approve Action' where PERM_ID = '170'
+ALTER TABLE KREW_INIT_RTE_NODE_INSTN_T CHANGE RTE_NODE_INSTN_ID RTE_NODE_INSTN_ID VARCHAR(40)
 /
 DELIMITER ;
